@@ -166,6 +166,10 @@ impl super::Kubectl {
         self.deployments(namespace).get(name).await
     }
 
+    pub async fn get_namespace(&self, name: &str) -> kube::Result<corev1::Namespace> {
+        self.namespaces().get(name).await
+    }
+
     pub async fn get_secret(&self, name: &str) -> kube::Result<corev1::Secret> {
         self.secrets(None).get(name).await
     }
